﻿
using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.IO;
using System.Windows.Forms;
using System.Xml;

using MindFusion.Reporting.WinForms;


namespace ReportingInvoiceEditor
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			invoicesTableAdapter1.Fill(nwindDataSet1.Invoices);
			ordersTableAdapter1.Fill(nwindDataSet1.Orders);

			reportEditor1.AddDataSource(nwindDataSet1.Orders, "Orders");
			reportEditor1.AddDataSource(nwindDataSet1.Invoices, "Invoices");
			reportEditor1.OpenReport(@"Invoice.xml");
		}

		protected override void OnClosing(CancelEventArgs e)
		{
			base.OnClosing(e);

			reportEditor1.SaveReport(@"Invoice.xml");
		}

		/// <summary>
		/// Form.ProcessCmdKey override.
		/// </summary>
		protected override bool ProcessCmdKey(ref Message msg, Keys keyData)
		{
			if (msg.Msg == 0x100 || // WM_KEYDOWN
				msg.Msg == 0x104) // WM_SYSKEYDOWN
			{
				// Check the previous key state to ensure that the command will be invoked only
				// once regardless of whether the user holds down the shortcut key
				if ((msg.LParam.ToInt64() & 0x40000000) == 0)
				{
					// Del = Delete Selection (Note: We don't use menu shortcut key to avoid
					// blocking all input of the DEL key)
					if ((keyData & Keys.KeyCode) == Keys.Delete)
					{
						if (reportEditor1.IsDesignerFocused)
							return reportEditor1.InvokeCommand(StandardCommands.Delete);
					}
				}
			}

			return base.ProcessCmdKey(ref msg, keyData);
		}

		private void printToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var printer = new ReportPrinter();
			printer.Report = reportEditor1.Report;
			printer.Report.Run();
			printer.Print();
		}

		private void printPreviewToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var printer = new ReportPrinter();
			printer.Report = reportEditor1.Report;
			printer.Report.Run();

			var preview = new PrintPreviewForm();
			preview.Document = printer;
			preview.ShowDialog();

		}

		private void exitToolStripMenuItem_Click(object sender, EventArgs e)
		{
			Close();
		}

		private void undoToolStripMenuItem_Click(object sender, EventArgs e)
		{
			reportEditor1.Undo();
		}

		private void redoToolStripMenuItem_Click(object sender, EventArgs e)
		{
			reportEditor1.Redo();
		}
	}
}
